Class: RubyRest::Atom::DomainFormatter
- Inherits:
-
Object
- Object
- RubyRest::Atom::DomainFormatter
- Defined in:
- lib/rubyrest/atom.rb
Direct Known Subclasses
Instance Method Summary collapse
-
#app ⇒ Object
shortcut to the application.
-
#initialize(parent) ⇒ DomainFormatter
constructor
Creates a new formatter, as a child of the specified parent formatter.
Constructor Details
#initialize(parent) ⇒ DomainFormatter
Creates a new formatter, as a child of the specified parent formatter
179 180 181 |
# File 'lib/rubyrest/atom.rb', line 179 def initialize( parent ) @parent = parent end |
Instance Method Details
#app ⇒ Object
shortcut to the application
184 185 186 |
# File 'lib/rubyrest/atom.rb', line 184 def app @parent.app end |