Module: RubyRest::Atom::Entry

Defined in:
lib/rubyrest/atom.rb

Overview

This module provides some default, arbitrary implementations for methods required by RubyRest in order to provide an Atom Entry representation out of a domain object.

Developpers can choose whether to use this implementation or to provide their own.

Defined Under Namespace

Classes: Document

Instance Method Summary collapse

Instance Method Details

#atom_authorObject

Not a very relevant buy necessary information



146
147
148
# File 'lib/rubyrest/atom.rb', line 146

def atom_author
  self.createdby
end

#atom_idObject

Returns the generated token



136
137
138
# File 'lib/rubyrest/atom.rb', line 136

def atom_id
  self.id
end

#atom_summaryObject

Returns the Atom Entry Summary. Synonym of atom_title



131
132
133
# File 'lib/rubyrest/atom.rb', line 131

def atom_summary
  atom_title
end

#atom_titleObject

Returns the Atom Entry title



126
127
128
# File 'lib/rubyrest/atom.rb', line 126

def atom_title
  self.name
end

#atom_updatedObject

Returns Time.now



141
142
143
# File 'lib/rubyrest/atom.rb', line 141

def atom_updated
  self.updated
end