Module: RubyRest::Atom::Entry
- Defined in:
- lib/rubyrest/atom.rb
Overview
This module provides some default, arbitrary implementations for methods required by RubyRest in order to provide an Atom Entry representation out of a domain object.
Developpers can choose whether to use this implementation or to provide their own.
Defined Under Namespace
Classes: Document
Instance Method Summary collapse
-
#atom_author ⇒ Object
Not a very relevant buy necessary information.
-
#atom_id ⇒ Object
Returns the generated token.
-
#atom_summary ⇒ Object
Returns the Atom Entry Summary.
-
#atom_title ⇒ Object
Returns the Atom Entry title.
-
#atom_updated ⇒ Object
Returns Time.now.
Instance Method Details
#atom_author ⇒ Object
Not a very relevant buy necessary information
146 147 148 |
# File 'lib/rubyrest/atom.rb', line 146 def self.createdby end |
#atom_id ⇒ Object
Returns the generated token
136 137 138 |
# File 'lib/rubyrest/atom.rb', line 136 def atom_id self.id end |
#atom_summary ⇒ Object
Returns the Atom Entry Summary. Synonym of atom_title
131 132 133 |
# File 'lib/rubyrest/atom.rb', line 131 def atom_summary atom_title end |
#atom_title ⇒ Object
Returns the Atom Entry title
126 127 128 |
# File 'lib/rubyrest/atom.rb', line 126 def atom_title self.name end |
#atom_updated ⇒ Object
Returns Time.now
141 142 143 |
# File 'lib/rubyrest/atom.rb', line 141 def atom_updated self.updated end |